ExpectationNormalizedMetric
===========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ExpectationNormalizedMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ExpectationNormalizedMetric.base_cls
      ~ExpectationNormalizedMetric.binarize
      ~ExpectationNormalizedMetric.closed_expectation
      ~ExpectationNormalizedMetric.closed_variance
      ~ExpectationNormalizedMetric.key
      ~ExpectationNormalizedMetric.needs_candidates
      ~ExpectationNormalizedMetric.supported_rank_types
      ~ExpectationNormalizedMetric.supports_weights
      ~ExpectationNormalizedMetric.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~ExpectationNormalizedMetric.__call__
      ~ExpectationNormalizedMetric.adjust
      ~ExpectationNormalizedMetric.expected_value
      ~ExpectationNormalizedMetric.extra_repr
      ~ExpectationNormalizedMetric.get_coefficients
      ~ExpectationNormalizedMetric.get_description
      ~ExpectationNormalizedMetric.get_link
      ~ExpectationNormalizedMetric.get_range
      ~ExpectationNormalizedMetric.get_sampled_values
      ~ExpectationNormalizedMetric.iter_extra_repr
      ~ExpectationNormalizedMetric.numeric_expected_value
      ~ExpectationNormalizedMetric.numeric_expected_value_with_ci
      ~ExpectationNormalizedMetric.numeric_variance
      ~ExpectationNormalizedMetric.numeric_variance_with_ci
      ~ExpectationNormalizedMetric.std
      ~ExpectationNormalizedMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: base_cls
   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: key
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
